<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\KitchenBlog\Http\Requests\KitchenCategoryRequest;
use Litecms\KitchenBlog\Interfaces\KitchenCategoryRepositoryInterface;
use Litecms\KitchenBlog\Models\KitchenCategory;

/**
 * Resource controller class for kitchen_category.
 */
class KitchenCategoryResourceController extends BaseController
{

    /**
     * Initialize kitchen_category resource controller.
     *
     * @param type KitchenCategoryRepositoryInterface $kitchen_category
     *
     * @return null
     */
    public function __construct(KitchenCategoryRepositoryInterface $kitchen_category)
    {
        parent::__construct();
        $this->repository = $kitchen_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenCategoryResourceCriteria::class);
    }

    /**
     * Display a list of kitchen_category.
     *
     * @return Response
     */
    public function index(KitchenCategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenCategoryPresenter::class)
                ->$function();
        }

        $kitchen_categories = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('kitchen_blog::kitchen_category.names'))
            ->view('kitchen_blog::kitchen_category.index', true)
            ->data(compact('kitchen_categories', 'view'))
            ->output();
    }

    /**
     * Display kitchen_category.
     *
     * @param Request $request
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function show(KitchenCategoryRequest $request, KitchenCategory $kitchen_category)
    {

        if ($kitchen_category->exists) {
            $view = 'kitchen_blog::kitchen_category.show';
        } else {
            $view = 'kitchen_blog::kitchen_category.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('kitchen_blog::kitchen_category.name'))
            ->data(compact('kitchen_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new kitchen_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(KitchenCategoryRequest $request)
    {

        $kitchen_category = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('kitchen_blog::kitchen_category.name')) 
            ->view('kitchen_blog::kitchen_category.create', true) 
            ->data(compact('kitchen_category'))
            ->output();
    }

    /**
     * Create new kitchen_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $kitchen_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_category/' . $kitchen_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/kitchen_blog/kitchen_category'))
                ->redirect();
        }

    }

    /**
     * Show kitchen_category for editing.
     *
     * @param Request $request
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function edit(KitchenCategoryRequest $request, KitchenCategory $kitchen_category)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('kitchen_blog::kitchen_category.name'))
            ->view('kitchen_blog::kitchen_category.edit', true)
            ->data(compact('kitchen_category'))
            ->output();
    }

    /**
     * Update the kitchen_category.
     *
     * @param Request $request
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function update(KitchenCategoryRequest $request, KitchenCategory $kitchen_category)
    {
        try {
            $attributes = $request->all();

            $kitchen_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_category/' . $kitchen_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_category/' . $kitchen_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the kitchen_category.
     *
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function destroy(KitchenCategoryRequest $request, KitchenCategory $kitchen_category)
    {
        try {

            $kitchen_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_category/' . $kitchen_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple kitchen_category.
     *
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function delete(KitchenCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('kitchen_blog/kitchen_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted kitchen_categories.
     *
     * @param Model   $kitchen_category
     *
     * @return Response
     */
    public function restore(KitchenCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('kitchen_blog::kitchen_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/kitchen_blog/kitchen_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_category/'))
                ->redirect();
        }

    }

}
