<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\KitchenBlog\Http\Requests\KitchenCommentRequest;
use Litecms\KitchenBlog\Interfaces\KitchenCommentRepositoryInterface;
use Litecms\KitchenBlog\Models\KitchenComment;

/**
 * Resource controller class for kitchen_comment.
 */
class KitchenCommentResourceController extends BaseController
{

    /**
     * Initialize kitchen_comment resource controller.
     *
     * @param type KitchenCommentRepositoryInterface $kitchen_comment
     *
     * @return null
     */
    public function __construct(KitchenCommentRepositoryInterface $kitchen_comment)
    {
        parent::__construct();
        $this->repository = $kitchen_comment;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenCommentResourceCriteria::class);
    }

    /**
     * Display a list of kitchen_comment.
     *
     * @return Response
     */
    public function index(KitchenCommentRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenCommentPresenter::class)
                ->$function();
        }

        $kitchen_comments = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('kitchen_blog::kitchen_comment.names'))
            ->view('kitchen_blog::kitchen_comment.index', true)
            ->data(compact('kitchen_comments', 'view'))
            ->output();
    }

    /**
     * Display kitchen_comment.
     *
     * @param Request $request
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function show(KitchenCommentRequest $request, KitchenComment $kitchen_comment)
    {

        if ($kitchen_comment->exists) {
            $view = 'kitchen_blog::kitchen_comment.show';
        } else {
            $view = 'kitchen_blog::kitchen_comment.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('kitchen_blog::kitchen_comment.name'))
            ->data(compact('kitchen_comment'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new kitchen_comment.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(KitchenCommentRequest $request)
    {

        $kitchen_comment = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('kitchen_blog::kitchen_comment.name')) 
            ->view('kitchen_blog::kitchen_comment.create', true) 
            ->data(compact('kitchen_comment'))
            ->output();
    }

    /**
     * Create new kitchen_comment.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenCommentRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $kitchen_comment                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen_comment.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_comment/' . $kitchen_comment->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/kitchen_blog/kitchen_comment'))
                ->redirect();
        }

    }

    /**
     * Show kitchen_comment for editing.
     *
     * @param Request $request
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function edit(KitchenCommentRequest $request, KitchenComment $kitchen_comment)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('kitchen_blog::kitchen_comment.name'))
            ->view('kitchen_blog::kitchen_comment.edit', true)
            ->data(compact('kitchen_comment'))
            ->output();
    }

    /**
     * Update the kitchen_comment.
     *
     * @param Request $request
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function update(KitchenCommentRequest $request, KitchenComment $kitchen_comment)
    {
        try {
            $attributes = $request->all();

            $kitchen_comment->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen_comment.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_comment/' . $kitchen_comment->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_comment/' . $kitchen_comment->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the kitchen_comment.
     *
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function destroy(KitchenCommentRequest $request, KitchenComment $kitchen_comment)
    {
        try {

            $kitchen_comment->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_comment.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_comment/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_comment/' . $kitchen_comment->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple kitchen_comment.
     *
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function delete(KitchenCommentRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_comment.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('kitchen_blog/kitchen_comment'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_comment'))
                ->redirect();
        }

    }

    /**
     * Restore deleted kitchen_comments.
     *
     * @param Model   $kitchen_comment
     *
     * @return Response
     */
    public function restore(KitchenCommentRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('kitchen_blog::kitchen_comment.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/kitchen_blog/kitchen_comment'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_comment/'))
                ->redirect();
        }

    }

}
