<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\KitchenBlog\Http\Requests\KitchenRequest;
use Litecms\KitchenBlog\Interfaces\KitchenRepositoryInterface;
use Litecms\KitchenBlog\Models\Kitchen;

/**
 * Resource controller class for kitchen.
 */
class KitchenResourceController extends BaseController
{

    /**
     * Initialize kitchen resource controller.
     *
     * @param type KitchenRepositoryInterface $kitchen
     *
     * @return null
     */
    public function __construct(KitchenRepositoryInterface $kitchen)
    {
        parent::__construct();
        $this->repository = $kitchen;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenResourceCriteria::class);
    }

    /**
     * Display a list of kitchen.
     *
     * @return Response
     */
    public function index(KitchenRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenPresenter::class)
                ->$function();
        }

        $kitchens = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('kitchen_blog::kitchen.names'))
            ->view('kitchen_blog::kitchen.index', true)
            ->data(compact('kitchens', 'view'))
            ->output();
    }

    /**
     * Display kitchen.
     *
     * @param Request $request
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function show(KitchenRequest $request, Kitchen $kitchen)
    {

        if ($kitchen->exists) {
            $view = 'kitchen_blog::kitchen.show';
        } else {
            $view = 'kitchen_blog::kitchen.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('kitchen_blog::kitchen.name'))
            ->data(compact('kitchen'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new kitchen.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(KitchenRequest $request)
    {

        $kitchen = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('kitchen_blog::kitchen.name')) 
            ->view('kitchen_blog::kitchen.create', true) 
            ->data(compact('kitchen'))
            ->output();
    }

    /**
     * Create new kitchen.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $kitchen                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/kitchen_blog/kitchen'))
                ->redirect();
        }

    }

    /**
     * Show kitchen for editing.
     *
     * @param Request $request
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function edit(KitchenRequest $request, Kitchen $kitchen)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('kitchen_blog::kitchen.name'))
            ->view('kitchen_blog::kitchen.edit', true)
            ->data(compact('kitchen'))
            ->output();
    }

    /**
     * Update the kitchen.
     *
     * @param Request $request
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function update(KitchenRequest $request, Kitchen $kitchen)
    {
        try {
            $attributes = $request->all();

            $kitchen->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the kitchen.
     *
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function destroy(KitchenRequest $request, Kitchen $kitchen)
    {
        try {

            $kitchen->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple kitchen.
     *
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function delete(KitchenRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('kitchen_blog/kitchen'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen'))
                ->redirect();
        }

    }

    /**
     * Restore deleted kitchens.
     *
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function restore(KitchenRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('kitchen_blog::kitchen.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/kitchen_blog/kitchen'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen/'))
                ->redirect();
        }

    }

}
