<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\KitchenBlog\Http\Requests\KitchenTagRequest;
use Litecms\KitchenBlog\Interfaces\KitchenTagRepositoryInterface;
use Litecms\KitchenBlog\Models\KitchenTag;

/**
 * Resource controller class for kitchen_tag.
 */
class KitchenTagResourceController extends BaseController
{

    /**
     * Initialize kitchen_tag resource controller.
     *
     * @param type KitchenTagRepositoryInterface $kitchen_tag
     *
     * @return null
     */
    public function __construct(KitchenTagRepositoryInterface $kitchen_tag)
    {
        parent::__construct();
        $this->repository = $kitchen_tag;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenTagResourceCriteria::class);
    }

    /**
     * Display a list of kitchen_tag.
     *
     * @return Response
     */
    public function index(KitchenTagRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenTagPresenter::class)
                ->$function();
        }

        $kitchen_tags = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('kitchen_blog::kitchen_tag.names'))
            ->view('kitchen_blog::kitchen_tag.index', true)
            ->data(compact('kitchen_tags', 'view'))
            ->output();
    }

    /**
     * Display kitchen_tag.
     *
     * @param Request $request
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function show(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {

        if ($kitchen_tag->exists) {
            $view = 'kitchen_blog::kitchen_tag.show';
        } else {
            $view = 'kitchen_blog::kitchen_tag.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('kitchen_blog::kitchen_tag.name'))
            ->data(compact('kitchen_tag'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new kitchen_tag.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(KitchenTagRequest $request)
    {

        $kitchen_tag = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('kitchen_blog::kitchen_tag.name')) 
            ->view('kitchen_blog::kitchen_tag.create', true) 
            ->data(compact('kitchen_tag'))
            ->output();
    }

    /**
     * Create new kitchen_tag.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenTagRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $kitchen_tag                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen_tag.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/kitchen_blog/kitchen_tag'))
                ->redirect();
        }

    }

    /**
     * Show kitchen_tag for editing.
     *
     * @param Request $request
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function edit(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('kitchen_blog::kitchen_tag.name'))
            ->view('kitchen_blog::kitchen_tag.edit', true)
            ->data(compact('kitchen_tag'))
            ->output();
    }

    /**
     * Update the kitchen_tag.
     *
     * @param Request $request
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function update(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        try {
            $attributes = $request->all();

            $kitchen_tag->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen_tag.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the kitchen_tag.
     *
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function destroy(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        try {

            $kitchen_tag->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_tag.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('kitchen_blog/kitchen_tag/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple kitchen_tag.
     *
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function delete(KitchenTagRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_tag.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('kitchen_blog/kitchen_tag'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_tag'))
                ->redirect();
        }

    }

    /**
     * Restore deleted kitchen_tags.
     *
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function restore(KitchenTagRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('kitchen_blog::kitchen_tag.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/kitchen_blog/kitchen_tag'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kitchen_blog/kitchen_tag/'))
                ->redirect();
        }

    }

}
